@@ -85,8 +85,7 @@ ctKalman<-function(kpars,datalong,
   yupd<-list()
   yupdcov<-list()
   
-  etaprior[[1]]<-kpars$T0MEANS
-  if(ntdpred > 0) etaprior[[1]]<-etaprior[[1]]+kpars$TDPREDEFFECT %*% t(datalong[1,TDpredNames,drop=FALSE])
+  etaprior[[1]]<-kpars$T0MEANS #tdpreds added below
   etapriorcov[[1]]<-kpars$T0VAR[diffusionindices,diffusionindices,drop=FALSE]
   loglik<-rep(0,nrow(datalong))
   observed<-list()
@@ -99,7 +98,7 @@ ctKalman<-function(kpars,datalong,
     
     if(continuoustime){
       dt<-datalong[rowi,timecol]-datalong[max(c(1,rowi-1)),timecol]
-      discreteDRIFT[[rowi]] <- OpenMx::expm(kpars$DRIFT * dt)
+      discreteDRIFT[[rowi]] <- expm(kpars$DRIFT * dt)
       discreteCINT[[rowi]] <- solve(kpars$DRIFT, (discreteDRIFT[[rowi]] - diag(nlatent))) %*% kpars$CINT
       discreteDIFFUSION[[rowi]] <- asymDIFFUSION - (discreteDRIFT[[rowi]][diffusionindices,diffusionindices,drop=FALSE] %*% 
           asymDIFFUSION %*% t(discreteDRIFT[[rowi]][diffusionindices,diffusionindices,drop=FALSE]))
